@@ -48,4 +48,9 @@ class AniAbstractButton(QAbstractButton):
     def leaveEvent(self, e):
         self.__animation.setDirection(QAbstractAnimation.Backward)
         self.__animation.start()
-        return super().leaveEvent(e)
\ No newline at end of file
+        return super().leaveEvent(e)
+
+    def event(self, e):
+        if e.type() == 17:
+            self._initStyle(self.__animation.startValue())
+        return super().event(e)
\ No newline at end of file
